package com.ruoyi.system.service.impl;

import com.ruoyi.system.domain.TPatient;
import com.ruoyi.system.domain.resp.PlatformDayPlanResp;
import com.ruoyi.system.domain.resp.WeekMonthPersonCountResp;
import com.ruoyi.system.domain.resp.WeekMonthTimeResp;
import com.ruoyi.system.mapper.TRecordMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author zhuqing
 * @Date 2022/8/9
 */
@Component
public class PlatformService {

    @Autowired
    private TRecordMapper tRecordMapper;

    /**
     * 设备统计各个个数查询
     * @param hospitalId
     * @param doctorId
     * @return
     */
    public Map<String, Integer> equCount(Long hospitalId, Long doctorId) {
        //就诊总数
        int all = tRecordMapper.selectEquCount(hospitalId, doctorId, "1", null, null,null);
        //本月总数
        int month = tRecordMapper.selectEquCount(hospitalId, doctorId, "1", 1L, null,null);
        //本周总数
        int week = tRecordMapper.selectEquCount(hospitalId, doctorId, "1", null, 1L,null);
        //今日预约
        int day = tRecordMapper.selectEquCount(hospitalId, doctorId, "0", null, null,1L);
        Map<String, Integer> map = new HashMap<String, Integer>(){{
            put("all",all);
            put("month",month);
            put("week",week);
            put("day",day);
        }};
        return map;
    }

    /**
     * 今日就诊计划
     * @param hospitalId
     * @param doctorId
     * @return
     */
    public List<PlatformDayPlanResp> dayPlan(Long hospitalId, Long doctorId) {
        return tRecordMapper.dayPlan(hospitalId, doctorId);
    }

    /**
     * 周/月就诊人数统计
     * @param hospitalId
     * @param doctorId
     * @param weekMonth
     * @return
     */
    public List<WeekMonthPersonCountResp> weekMonthPersonCount(Long hospitalId, Long doctorId,Long weekMonth) {
        return tRecordMapper.weekMonthPersonCount(hospitalId, doctorId,weekMonth);
    }

    /**
     * 年龄分布
     * @param hospitalId
     * @param doctorId
     * @return
     */
    public Map<String,Long> ageCount(Long hospitalId, Long doctorId) {
        List<TPatient> tPatients = tRecordMapper.ageCount(hospitalId, doctorId);
        //20-30
        long count20 = tPatients.stream().filter(a -> a.getAge() >= 20 && a.getAge() <= 30).count();
        //31-40
        long count31 = tPatients.stream().filter(a -> a.getAge() >= 31 && a.getAge() <= 40).count();
        //41-50
        long count41 = tPatients.stream().filter(a -> a.getAge() >= 41 && a.getAge() <= 50).count();
        //51-
        long count51 = tPatients.stream().filter(a -> a.getAge() >= 51).count();
        Map<String,Long> map = new HashMap<String,Long>(){{
            put("count20",count20);
            put("count31",count31);
            put("count41",count41);
            put("count51",count51);
        }};
        return map;
    }

    /**
     * 就诊时段统计
     * @param hospitalId
     * @param doctorId
     * @param weekMonth
     * @return
     */
    public Map<String,Integer> weekMonthTimeCount(Long hospitalId,Long doctorId,Long weekMonth){
        Map<String,Integer> map = new HashMap<>();
        List<WeekMonthTimeResp> weekMonthTimeResps = tRecordMapper.weekMonthTimeCount(hospitalId, doctorId, weekMonth);
        //0-3
        int sum0 = weekMonthTimeResps.stream().filter(a -> a.getCreateTime() >= 0 && a.getCreateTime() < 3).mapToInt(WeekMonthTimeResp::getCount).sum();
        //3-6
        int sum3 = weekMonthTimeResps.stream().filter(a -> a.getCreateTime() >= 3 && a.getCreateTime() < 6).mapToInt(WeekMonthTimeResp::getCount).sum();
        //6-9
        int sum6 = weekMonthTimeResps.stream().filter(a -> a.getCreateTime() >= 6 && a.getCreateTime() < 9).mapToInt(WeekMonthTimeResp::getCount).sum();
        //9-12
        int sum9 = weekMonthTimeResps.stream().filter(a -> a.getCreateTime() >= 9 && a.getCreateTime() < 12).mapToInt(WeekMonthTimeResp::getCount).sum();
        //12-15
        int sum12 = weekMonthTimeResps.stream().filter(a -> a.getCreateTime() >= 12 && a.getCreateTime() < 15).mapToInt(WeekMonthTimeResp::getCount).sum();
        //15-18
        int sum15 = weekMonthTimeResps.stream().filter(a -> a.getCreateTime() >= 15 && a.getCreateTime() < 18).mapToInt(WeekMonthTimeResp::getCount).sum();
        //18-21
        int sum18 = weekMonthTimeResps.stream().filter(a -> a.getCreateTime() >= 18 && a.getCreateTime() < 21).mapToInt(WeekMonthTimeResp::getCount).sum();
        //21-24
        int sum21 = weekMonthTimeResps.stream().filter(a -> a.getCreateTime() >= 21 && a.getCreateTime() <= 24).mapToInt(WeekMonthTimeResp::getCount).sum();
        map.put("sum0",sum0);map.put("sum3",sum3);map.put("sum6",sum6);map.put("sum9",sum9);map.put("sum12",sum12);map.put("sum15",sum15);map.put("sum18",sum18);
        map.put("sum21",sum21);
        return map;
    }
}
